@@ -524,6 +524,14 @@ ghttp_get_header(ghttp_request *a_request,
 			    a_hdr);
 }
 
+int
+ghttp_get_header_names(ghttp_request *a_request,
+		       char ***a_hdrs, int *a_num_hdrs)
+{
+  return http_hdr_get_headers(a_request->resp->headers,
+			      a_hdrs, a_num_hdrs);
+}
+
 const char *
 ghttp_get_error(ghttp_request *a_request)
 {
