@@ -145,7 +145,7 @@ http_resp_read_headers(http_resp *a_resp, http_trans_conn *a_conn)
     }
   l_ptr = a_conn->io_buf;
   /* can you say PARANOID?  I thought you could. */
-  if (memcmp(l_ptr, "HTTP", 4) != 0)
+  if (strncmp(l_ptr, "HTTP", 4) != 0)
     {
       a_conn->errstr = "The http response line did not begin with \"HTTP\"";
       l_return = HTTP_TRANS_ERR;
